apply_sneak_edge_prevention

Function apply_sneak_edge_prevention 

fn apply_sneak_edge_prevention(
    state: &EntityPhysicsState,
    delta: DVec3,
    aabb: &WorldAabb,
    world: &dyn CollisionWorld,
) -> DVec3
Applies sneak-edge prevention to keep player from walking off blocks.

When crouching, checks if the movement would cause the player to fall off a block edge. If so, clips the movement to keep them on the block.

Matches: Player.maybeBackOffFromEdge(Vec3, MoverType)